"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.root = exports.parseHTML = exports.merge = exports.contains = exports.select = exports.load = void 0;
var tslib_1 = require("tslib");
/**
 * Types used in signatures of Cheerio methods.
 *
 * @category Cheerio
 */
tslib_1.__exportStar(require("./types"), exports);
var load_1 = require("./load");
var parse_1 = require("./parse");
var parse5_adapter_1 = require("./parsers/parse5-adapter");
var dom_serializer_1 = tslib_1.__importDefault(require("dom-serializer"));
var htmlparser2_1 = require("htmlparser2");
var parse = parse_1.getParse(function (content, options, isDocument) {
    return options.xmlMode || options._useHtmlParser2
        ? htmlparser2_1.parseDocument(content, options)
        : parse5_adapter_1.parseWithParse5(content, options, isDocument);
});
// Duplicate docs due to https://github.com/TypeStrong/typedoc/issues/1616
/**
 * Create a querying function, bound to a document created from the provided markup.
 *
 * Note that similar to web browser contexts, this operation may introduce
 * `<html>`, `<head>`, and `<body>` elements; set `isDocument` to `false` to
 * switch to fragment mode and disable this.
 *
 * @param content - Markup to be loaded.
 * @param options - Options for the created instance.
 * @param isDocument - Allows parser to be switched to fragment mode.
 * @returns The loaded document.
 * @see {@link https://cheerio.js.org#loading} for additional usage information.
 */
exports.load = load_1.getLoad(parse, function (dom, options) {
    return options.xmlMode || options._useHtmlParser2
        ? dom_serializer_1.default(dom, options)
        : parse5_adapter_1.renderWithParse5(dom);
});
/**
 * The default cheerio instance.
 *
 * @deprecated Use the function returned by `load` instead.
 */
exports.default = exports.load([]);
var cheerio_select_1 = require("cheerio-select");
/**
 * Extension points for adding custom pseudo selectors.
 *
 * @example <caption>Adds a custom pseudo selector `:classic`, which matches
 * some fun HTML elements that are no more.</caption>
 *
 * ```js
 * import { load, select } from 'cheerio';
 *
 * // Aliases are short hands for longer HTML selectors
 * select.aliases.classic = 'marquee,blink';
 *
 * const $ = load(doc);
 * $(':classic').html();
 * ```
 */
exports.select = { filters: cheerio_select_1.filters, pseudos: cheerio_select_1.pseudos, aliases: cheerio_select_1.aliases };
var staticMethods = tslib_1.__importStar(require("./static"));
/**
 * In order to promote consistency with the jQuery library, users are encouraged
 * to instead use the static method of the same name.
 *
 * @deprecated
 * @example
 *
 * ```js
 * const $ = cheerio.load('<div><p></p></div>');
 *
 * $.contains($('div').get(0), $('p').get(0));
 * //=> true
 *
 * $.contains($('p').get(0), $('div').get(0));
 * //=> false
 * ```
 *
 * @returns {boolean}
 */
exports.contains = staticMethods.contains;
/**
 * In order to promote consistency with the jQuery library, users are encouraged
 * to instead use the static method of the same name.
 *
 * @deprecated
 * @example
 *
 * ```js
 * const $ = cheerio.load('');
 *
 * $.merge([1, 2], [3, 4]);
 * //=> [1, 2, 3, 4]
 * ```
 */
exports.merge = staticMethods.merge;
/**
 * In order to promote consistency with the jQuery library, users are encouraged
 * to instead use the static method of the same name as it is defined on the
 * "loaded" Cheerio factory function.
 *
 * @deprecated See {@link static/parseHTML}.
 * @example
 *
 * ```js
 * const $ = cheerio.load('');
 * $.parseHTML('<b>markup</b>');
 * ```
 */
exports.parseHTML = staticMethods.parseHTML;
/**
 * Users seeking to access the top-level element of a parsed document should
 * instead use the `root` static method of a "loaded" Cheerio function.
 *
 * @deprecated
 * @example
 *
 * ```js
 * const $ = cheerio.load('');
 * $.root();
 * ```
 */
exports.root = staticMethods.root;
